;; db30ref.el -- helper code to call up named topics from the 
;;               db30ref.hlp WinHelp file.
;;
;; This file is part of the "WinHelp - Rendition of the DocBook Reference"
;; distribution.
;;
;; Author: tpla@ovidius.com (Thomas Plass) 10-Jan-1999
;; 
;; PSGML glue code snarfed from PSGML by Lennart Staflin.
;;
;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License
;; as published by the Free Software Foundation; either version 2
;; of the License, or (at your option) any later version.
;; 
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;; 
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;;
;;;; Commentary:
;;
;; Installation:
;; 
;; 1) To use this code, install the help file db30ref.hlp provided in the
;;    distribution and set the variable db30ref-helpfile to point to that
;;    location.  Install this file somewhere and load it your favourite way.
;; 
;; 2) Download and install the w32-help application containing a small
;;    executable which exposes the WinHelp API (though only partially) to
;;    the Emacs-Lisp code provided in that package.  W32-help may be
;;    obtained from http://www.i21.com/~tjump.
;; 
;;    The code below is tailored to using that application.  It
;;    must be changed when using a different program that calls the
;;    WinHelp API.
;; 
;; 3) (optional) Unless it's not installed already, download and install
;;    PSGML, an SGML mode by Lennart Staflin.
;; 
;;    Suggested key-binding for sgml mode:
;; 
;;    (define-key sgml-mode-map "\C-ch" 'help-on-docbook-element)
;;
;;    Note that the code makes no assumptions about the status of the DTD
;;    in use.  To avoid frustration, use it only when actually editing
;;    DocBook (or DocBook variants) instances...
;;
;; Usage:
;;
;; If not bound to a key, invoke the function contained in this file with
;; M-x help-on-docbook-element.  For details on its workings refer to the
;; docstring of that function.
;;
;;;; Code:

(defvar db30ref-helpfile "c:/windows/help/db30ref.hlp"
  "Name of the db30ref.hlp file.")



(defun help-on-docbook-element ()
  "Prompts for DocBook element name to display corresponding help topic.
Completion is available when invoked in a PSGML sgml-mode buffer.  
If invoked with a prefix arg, displays help on current element when used
in a PSGML buffer.  Otherwise uses the word point is on (or a nearby
word).
Invoke it with \\[help-on-docbook-element] (in current buffer).
Note that this function requires the w32-help package."

  (interactive)
  (or (fboundp 'w32-help-on-topic)
      (error (concat "required module w32-help.el not loaded"
                     " (available at http://www.i21.com/~tjump).")))
  (let* ((prompt "Help on DocBook element: ")
         (gi (if current-prefix-arg
                 (if (and (member (symbol-name major-mode) '("sgml-mode" "psgml-mode"))
                          (fboundp 'sgml-element-gi))
                     (sgml-element-gi (sgml-find-element-of (point)))
                   (current-word))
               (if (fboundp 'sgml-dtd-eltypes)
                   (completing-read prompt 
                                    (sgml-dtd-eltypes sgml-dtd-info)
                                    (function fboundp) 
                                    t 
                                    nil 
                                    nil)
                 (read-string prompt)))))
    (if (or (not gi)
            (not (string-match "^[a-zA-Z]" gi)))
        (error "help-on-docbook-element: invalid element name: \"%s\"" gi)
      (w32-help-on-topic (or db30ref-helpfile "db30ref.hlp") 
                         ;; !! Sigh, w32-help does not support the use of topic IDs.
                         ;;    Use the Index entry instead.
                         (concat gi " element")))))  

;; db30ref.el ends here
